@@ -376,12 +376,12 @@ static void update_icon (ConnectPlugin *c)
                 if (c->animate)
                 {
                     c->anim_frame = 0;
-                    gtk_image_set_from_pixbuf (GTK_IMAGE (c->tray_icon), c->anim[c->anim_frame]);
+                    set_image_from_pixbuf (c->tray_icon, c->anim[c->anim_frame]);
                 }
                 else
                 {
-                    set_taskbar_icon (c->tray_icon, "rpc-active", get_icon_size ());
                     c->anim_frame = -1;
+                    set_taskbar_icon (c->tray_icon, "rpc-active", get_icon_size ());
                 }
             }
             else
@@ -403,7 +403,7 @@ static gboolean animate (ConnectPlugin *c)
         {
             c->anim_frame++;
             if (c->anim_frame > (ANIM_FRAMES - 1)) c->anim_frame = 0;
-            gtk_image_set_from_pixbuf (GTK_IMAGE (c->tray_icon), c->anim[c->anim_frame]);
+            set_image_from_pixbuf (c->tray_icon, c->anim[c->anim_frame]);
         }
         else
         {
@@ -426,8 +426,8 @@ static void cache_animation (ConnectPlugin *c, gboolean clear)
     {
         if (clear && c->anim[count]) g_object_unref (c->anim[count]);
         iname = g_strdup_printf ("rpc-active%d", count);
-        c->anim[count] = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (), iname,
-            get_icon_size (), GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
+        c->anim[count] = gtk_icon_theme_load_icon_for_scale (gtk_icon_theme_get_default (), iname,
+            get_icon_size (), gtk_widget_get_scale_factor (c->tray_icon), GTK_ICON_LOOKUP_FORCE_SIZE, NULL);
         g_free (iname);
     }
 }
